fbdev: c2p - Rename c2p to c2p_planar

Signed-off-by: Geert Uytterhoeven <geert@linux-m68k.org>
diff --git a/drivers/video/Makefile b/drivers/video/Makefile
index 4fc29ea..be2b657 100644
--- a/drivers/video/Makefile
+++ b/drivers/video/Makefile
@@ -28,7 +28,7 @@
 obj-$(CONFIG_FB_DEFERRED_IO)   += fb_defio.o
 
 # Hardware specific drivers go first
-obj-$(CONFIG_FB_AMIGA)            += amifb.o c2p.o
+obj-$(CONFIG_FB_AMIGA)            += amifb.o c2p_planar.o
 obj-$(CONFIG_FB_ARC)              += arcfb.o
 obj-$(CONFIG_FB_CLPS711X)         += clps711xfb.o
 obj-$(CONFIG_FB_CYBER2000)        += cyber2000fb.o
diff --git a/drivers/video/amifb.c b/drivers/video/amifb.c
index b8e9a86..100f236 100644
--- a/drivers/video/amifb.c
+++ b/drivers/video/amifb.c
@@ -2159,9 +2159,9 @@
 			src += pitch;
 		}
 	} else {
-		c2p(info->screen_base, image->data, dx, dy, width, height,
-		    par->next_line, par->next_plane, image->width,
-		    info->var.bits_per_pixel);
+		c2p_planar(info->screen_base, image->data, dx, dy, width,
+			   height, par->next_line, par->next_plane,
+			   image->width, info->var.bits_per_pixel);
 	}
 }
 
diff --git a/drivers/video/c2p.h b/drivers/video/c2p.h
index 5364129..6c38d40 100644
--- a/drivers/video/c2p.h
+++ b/drivers/video/c2p.h
@@ -10,9 +10,9 @@
 
 #include <linux/types.h>
 
-extern void c2p(void *dst, const void *src, u32 dx, u32 dy, u32 width,
-		u32 height, u32 dst_nextline, u32 dst_nextplane,
-		u32 src_nextline, u32 bpp);
+extern void c2p_planar(void *dst, const void *src, u32 dx, u32 dy, u32 width,
+		       u32 height, u32 dst_nextline, u32 dst_nextplane,
+		       u32 src_nextline, u32 bpp);
 
 extern void c2p_iplan2(void *dst, const void *src, u32 dx, u32 dy, u32 width,
 		       u32 height, u32 dst_nextline, u32 src_nextline,
diff --git a/drivers/video/c2p.c b/drivers/video/c2p_planar.c
similarity index 92%
rename from drivers/video/c2p.c
rename to drivers/video/c2p_planar.c
index 1238c8b..ec7ac85 100644
--- a/drivers/video/c2p.c
+++ b/drivers/video/c2p_planar.c
@@ -71,7 +71,7 @@
 
 
     /*
      *  c2p - Copy 8-bit chunky image data to a planar frame buffer
      *  @dst: Starting address of the planar frame buffer
      *  @dx: Horizontal destination offset (in pixels)
      *  @dy: Vertical destination offset (in pixels)
@@ -83,8 +83,9 @@
      *  @bpp: Bits per pixel of the planar frame buffer (1-8)
      */
 
-void c2p(void *dst, const void *src, u32 dx, u32 dy, u32 width, u32 height,
-	 u32 dst_nextline, u32 dst_nextplane, u32 src_nextline, u32 bpp)
+void c2p_planar(void *dst, const void *src, u32 dx, u32 dy, u32 width,
+		u32 height, u32 dst_nextline, u32 dst_nextplane,
+		u32 src_nextline, u32 bpp)
 {
 	union {
 		u8 pixels[32];
@@ -150,6 +151,6 @@
 		dst += dst_nextline;
 	}
 }
-EXPORT_SYMBOL_GPL(c2p);
+EXPORT_SYMBOL_GPL(c2p_planar);
 
 MODULE_LICENSE("GPL");
@@ -71,7 +71,7 @@
 
     /*
-     *  c2p - Copy 8-bit chunky image data to a planar frame buffer
+     *  c2p_planar - Copy 8-bit chunky image data to a planar frame buffer
      *  @dst: Starting address of the planar frame buffer
      *  @dx: Horizontal destination offset (in pixels)